@@ -223,7 +223,7 @@ metadata. Currently the supplied coderef is executed as:
     foreign_alias     => The alias of the to-be-joined resultset (often matches relname),
     self_resultsource => The invocant's resultsource,
     foreign_relname   => The relationship name (does *not* always match foreign_alias),
-    self_rowobj       => The invocant itself in case of $row_obj->relationship
+    self_rowobj       => The invocant itself in case of a $result_object->$relationship call
   });
 
 =head3 attributes
@@ -428,7 +428,7 @@ $rel_name.
   $rs = $cd->related_resultset('tracks');           # has_many relationship
   $rs = $cd->tracks;
 
-This is the recommended way to transverse through relationships, based
+This is the recommended way to traverse through relationships, based
 on the L</accessor> name given in the relationship definition.
 
 This will return either a L<Result|DBIx::Class::Manual::ResultClass> or a
@@ -671,7 +671,7 @@ sub create_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data | @pk_values, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
+=item Arguments: $rel_name, \%col_data | @pk_values, { key => $unique_constraint, L<%attrs|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
 =item Return Value: L<$result|DBIx::Class::Manual::ResultClass> | undef
 
@@ -694,7 +694,7 @@ sub find_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
+=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
 =item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
@@ -715,7 +715,7 @@ sub find_or_new_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
+=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
 =item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
@@ -736,7 +736,7 @@ sub find_or_create_related {
 
 =over 4
 
-=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs?|DBIx::Class::ResultSet/ATTRIBUTES> }?
+=item Arguments: $rel_name, \%col_data, { key => $unique_constraint, L<%attrs|DBIx::Class::ResultSet/ATTRIBUTES> }?
 
 =item Return Value: L<$result|DBIx::Class::Manual::ResultClass>
 
@@ -845,7 +845,7 @@ sub update_from_related {
 
 =item Arguments: $rel_name, $cond?, L<\%attrs?|DBIx::Class::ResultSet/ATTRIBUTES>
 
-=item Return Value: L<$storage_rv|DBIx::Class::Storage>
+=item Return Value: $underlying_storage_rv
 
 =back
 
@@ -918,7 +918,7 @@ B<Currently only available for C<many_to_many> relationships.>
 
 =over 4
 
-=item Arguments: (\@hashrefs_of_col_data | L<@result_objs|DBIx::Class::Manual::ResultClass>), $link_vals?
+=item Arguments: (\@hashrefs_of_col_data | L<\@result_objs|DBIx::Class::Manual::ResultClass>), $link_vals?
 
 =item Return Value: not defined
 
