@@ -1050,23 +1050,23 @@ Store a collection of resultset attributes, that will be set on every
 L<DBIx::Class::ResultSet> produced from this result source.
 
 B<CAVEAT>: C<resultset_attributes> comes with its own set of issues and
-bugs!  While C<resultset_attributes> isn't deprecated per se, its usage is not
-recommended!
+bugs! While C<resultset_attributes> isn't deprecated per se, its usage is
+not recommended!
 
 Since relationships use attributes to link tables together, the "default"
 attributes you set may cause unpredictable and undesired behavior.  Furthermore,
 the defaults cannot be turned off, so you are stuck with them.
 
-In most cases, what you should actually be using is a custom function:
+In most cases, what you should actually be using are project-specific methods:
 
   package My::Schema::ResultSet::Artist;
   use base 'DBIx::Class::ResultSet';
   ...
 
-  # BAD!
+  # BAD IDEA!
   #__PACKAGE__->resultset_attributes({ prefetch => 'tracks' });
 
-  # GOOD!
+  # GOOD IDEA!
   sub with_tracks { shift->search({}, { prefetch => 'tracks' }) }
 
   # in your code
