@@ -1550,7 +1550,6 @@ sub _prep_for_execute {
 
 sub _gen_sql_bind {
   my ($self, $op, $ident, $args) = @_;
-  $args = [ $args ] unless (ref $args);
 
   my ($sql, @bind) = $self->sql_maker->$op(
     blessed($ident) ? $ident->from : $ident,
@@ -1562,7 +1561,7 @@ sub _gen_sql_bind {
       and
     $op eq 'select'
       and
-    first { ref $_ && @$_ > 1 && blessed($_->[1]) && $_->[1]->isa('DateTime') } @bind
+    first { blessed($_->[1]) && $_->[1]->isa('DateTime') } @bind
   ) {
     carp_unique 'DateTime objects passed to search() are not supported '
       . 'properly (InflateColumn::DateTime formats and settings are not '
@@ -1605,9 +1604,6 @@ sub _resolve_bindattrs {
     if (ref $_ ne 'ARRAY') {
       [{}, $_]
     }
-    elsif (@$_ == 1 && ref $_->[0] ne 'HASH') {
-      [{}, $_->[0]]
-    }
     elsif (! defined $_->[0]) {
       [{}, $_->[1]]
     }
